import { HttpException, HttpStatus, Injectable } from "@nestjs/common";
import { Constants } from "src/utils/constants";
import { CreateProductCategoryDto } from "./dto/create-product-category.dto";
import { UpdateProductCategoryDto } from "./dto/update-product-category.dto";
import { ProductCategory } from "./entities/product-category.entity";
import { ProductCategoryRepository } from "./product-category.repository";
import { ResponseUtils } from "src/utils/response.utils";
import { UploadedMulterFileI } from "src/modules/SpacesModule/SpacesService";
import { DoSpacesService } from "src/modules/SpacesModule/SpacesService/doSpacesService";

@Injectable()
export class ProductCategoryService {
    constructor(
      private readonly repository: ProductCategoryRepository,
      private readonly doSpaceService: DoSpacesService
    ) {
    }

    async create(
      dto: CreateProductCategoryDto,
      files: {
          image?: UploadedMulterFileI,
          featuredImage?: UploadedMulterFileI
      }
    ): Promise<any | Error> {
        if (files && files.image) {
            const photo: any = await this.doSpaceService.uploadFile(files.image[0], "ProductCategory/");
            dto.image = photo;
        }
        if (files && files.featuredImage) {
            const featuredImage: any = await this.doSpaceService.uploadFile(files.featuredImage[0], "ProductCategory/");
            dto.featuredImage = featuredImage;
        }
        const data = await this.repository.createEntity(dto);
        if (!data) {
            throw new HttpException(
              Constants.CREATE_FAILED,
              HttpStatus.BAD_REQUEST
            );
        }
        return ResponseUtils.successResponseHandler(201, "Product Category created successfully", "data", data);
    }

    async findAll(): Promise<ProductCategory[] | Error> {
        const data = await this.repository.findAll();
        if (!data) {
            throw new HttpException(
              Constants.NOT_FOUND,
              HttpStatus.NOT_FOUND
            );
        }
        return ResponseUtils.successResponseHandler(200, "Product Category list fetched successfully", "data", data);
    }

    async findOne(id: string): Promise<any | Error> {
        let data: any = await this.repository.findOneEntity(id);
        if (!data) {
            throw new HttpException(
              Constants.NOT_FOUND,
              HttpStatus.NOT_FOUND
            );
        }

        return ResponseUtils.successResponseHandler(200, "Product Category fetched successfully", "data", data);
    }

    async update(
      id: string,
      dto: UpdateProductCategoryDto,
      files: {
          image?: UploadedMulterFileI,
          featuredImage?: UploadedMulterFileI
      }
    ): Promise<ProductCategory | Error> {
        if (files && files.image) {
            const photo: any = await this.doSpaceService.uploadFile(files.image[0], "ProductCategory/");
            dto.image = photo;
        }

        if (files && files.featuredImage) {
            const featuredImage: any = await this.doSpaceService.uploadFile(files.featuredImage[0], "ProductCategory/");
            dto.featuredImage = featuredImage;
        }

        const data = await this.repository.updateProductCategory(id, dto);
        if (!data) {
            throw new HttpException(
              Constants.UPDATE_FAILED,
              HttpStatus.BAD_REQUEST
            );
        }
        return ResponseUtils.successResponseHandler(200, "Product Category updated successfully", "data", data);
    }

    async remove(id: string): Promise<boolean | Error> {
        const data = await this.repository.deleteEntity(id);
        if (!data) {
            throw new HttpException(
              Constants.NOT_FOUND,
              HttpStatus.BAD_REQUEST
            );
        }
        return ResponseUtils.buildDeletedData(data, 200, "Product Category deleted successfully");
    }
}
