import { Body, Controller, Delete, Get, Param, Patch, Post, UploadedFiles, UseGuards, UseInterceptors } from "@nestjs/common";
import { Constants } from "src/utils/constants";
import { RetailerServiceService } from "./retailer-service.service";
import { CreateRetailerServiceDto } from "./dto/create-retailer-service.dto";
import { FileFieldsInterceptor } from "@nestjs/platform-express";
import { UploadedMulterFileI } from "../../../SpacesModule/SpacesService";
import { AdminAuthGuard } from "src/core/guards/admin-auth.guard";
import { SearchRetailerDto } from "./entities/search-retailer.dto";

@Controller({ path: "retailer-service", version: Constants.API_VERSION_1 })

export class RetailerServiceController {
    constructor(private readonly service: RetailerServiceService) {
    }

    @Post()
    // @UseGuards(AdminAuthGuard)
    create(
      @Body() dto: CreateRetailerServiceDto
    ) {
        return this.service.create(dto);
    }

    @Get()
    // @UseGuards(AdminAuthGuard)
    findAll() {
        return this.service.findAll();
    }

    @Get(":id")
    // @UseGuards(AdminAuthGuard)
    findOne(@Param("id") id: string) {
        return this.service.findOne(id);
    }

    @Patch("/alpineiq-update/:id")
    updateAlpineIq(@Param("id") id: string, @Body() dto: any) {
        return this.service.updateAlpineIq(id, dto);
    }


    @Patch(":id")
    // @UseGuards(AdminAuthGuard)
    @UseInterceptors(FileFieldsInterceptor(
      [
          { name: "retailerImage", maxCount: 1 }
      ]
    ))
    update(
      @Param("id") id: string,
      @Body() dto: any,
      @UploadedFiles() files: {
          retailerImage?: UploadedMulterFileI
      }
    ) {
        return this.service.update(id, dto, files);
    }

    @Delete(":id")
    // @UseGuards(AdminAuthGuard)
    async remove(@Param("id") id: string) {
        return await this.service.remove(id);
    }

    @Get("/populate/elasticsearch")
    @UseGuards(AdminAuthGuard)
    async productPopulateElasticsearch() {
        let index: string;
        if (process.env.ENVIRONMENT == "local") {
            index = process.env.RETAILER_INDEX_DEV;
        } else {
            index = process.env.RETAILER_INDEX_PROD;
        }
        return await this.service.indexBulkData(index);
    }

    @Post("/elastic/search")
    async productElasticsearch(@Body() searchDto: SearchRetailerDto) {
        let index: string;
        if (process.env.ENVIRONMENT == "local") {
            index = process.env.RETAILER_INDEX_DEV;
        } else {
            index = process.env.RETAILER_INDEX_PROD;
        }
        return await this.service.search(index, searchDto);
    }
}
