import { Module } from "@nestjs/common";
import { JwtModule } from "@nestjs/jwt";
import { TypeOrmModule } from "@nestjs/typeorm";
import JwtConfigService from "src/core/jwt/jwt-config.service";
import JwtHelper from "src/core/jwt/jwt.helper";
import { UsersRepository } from "src/modules/users/user.repository";
import { DoSpacesServicerovider } from "../../../SpacesModule/SpacesService";
import { DoSpacesService } from "../../../SpacesModule/SpacesService/doSpacesService";
import { RetailerServiceController } from "./retailer-service.controller";
import { RetailerServiceRepository } from "./retailer-service.repository";
import { RetailerServiceService } from "./retailer-service.service";
import { ElasticsearchModule } from "@nestjs/elasticsearch";

@Module({
    imports: [
        JwtModule.registerAsync({
            useClass: JwtConfigService
        }),
        TypeOrmModule.forFeature([UsersRepository]),
        TypeOrmModule.forFeature([RetailerServiceRepository]),
        ElasticsearchModule.registerAsync({
            useFactory: async () => ({
                node: process.env.ELASTIC_NODE,
                auth: {
                    apiKey: process.env.ELASTIC_API_KEY
                },
                maxRetries: 10,
                requestTimeout: 10000
            })
        })
    ],
    controllers: [RetailerServiceController],
    providers: [RetailerServiceService, JwtHelper, DoSpacesService, DoSpacesServicerovider]
})
export class RetailerServiceModule {
}
